@@ -1048,20 +1048,20 @@ class TestValidators(unittest.TestCase):
         rtn = IS_STRONG(es=True, entropy=1, min=2)("a")
         self.assertEqual(rtn, ("a", "Minimum length is 2"))
         rtn = IS_STRONG(es=True, entropy=100)("abc123")
-        self.assertEqual(rtn, ("abc123", "Entropy (32.35) less than required (100)"))
+        self.assertEqual(rtn, ("abc123", "Password too simple (32.35/100)"))
         rtn = IS_STRONG(es=True, entropy=100)("and")
-        self.assertEqual(rtn, ("and", "Entropy (14.57) less than required (100)"))
+        self.assertEqual(rtn, ("and", "Password too simple (14.57/100)"))
         rtn = IS_STRONG(es=True, entropy=100)("aaa")
-        self.assertEqual(rtn, ("aaa", "Entropy (14.42) less than required (100)"))
+        self.assertEqual(rtn, ("aaa", "Password too simple (14.42/100)"))
         rtn = IS_STRONG(es=True, entropy=100)("a1d")
-        self.assertEqual(rtn, ("a1d", "Entropy (15.97) less than required (100)"))
+        self.assertEqual(rtn, ("a1d", "Password too simple (15.97/100)"))
         rtn = IS_STRONG(es=True, entropy=100)("añd")
         if PY2:
             self.assertEqual(
-                rtn, ("a\xc3\xb1d", "Entropy (18.13) less than required (100)")
+                rtn, ("a\xc3\xb1d", "Password too simple (18.13/100)")
             )
         else:
-            self.assertEqual(rtn, ("añd", "Entropy (18.13) less than required (100)"))
+            self.assertEqual(rtn, ("añd", "Password too simple (18.13/100)"))
         rtn = IS_STRONG()("********")
         self.assertEqual(rtn, ("********", None))
         rtn = IS_STRONG(es=True, max=4)("abcde")
